Struct Union
pub struct Union<T>where
T: Strategy,{
options: Vec<(u32, Arc<T>)>,
}Expand description
A Strategy which picks from one of several delegate Strategys.
See Strategy::prop_union().
Fields
options: Vec<(u32, Arc<T>)>Implementations
impl<T> Union<T>where
T: Strategy,
impl<T> Union<T>where
T: Strategy,
pub fn new(options: impl IntoIterator<Item = T>) -> Union<T>
pub fn new(options: impl IntoIterator<Item = T>) -> Union<T>
Create a strategy which selects uniformly from the given delegate strategies.
When shrinking, after maximal simplification of the chosen element, the strategy will move to earlier options and continue simplification with those.
Panics
Panics if options is empty.
pub fn new_weighted(options: Vec<(u32, T)>) -> Union<T>
pub fn new_weighted(options: Vec<(u32, T)>) -> Union<T>
Create a strategy which selects from the given delegate strategies.
Each strategy is assigned a non-zero weight which determines how frequently that strategy is chosen. For example, a strategy with a weight of 2 will be chosen twice as frequently as one with a weight of 1.
Panics
Panics if options is empty or any element has a weight of 0.
Panics if the sum of the weights overflows a u32.